==> bouml_2.5.2.tar.gz: bouml_2.5.2/src/dialog/StateDialog.cpp <==
// *************************************************************************
//
// Copyright (C) 2004,2005 Bruno PAGES  All rights reserved.
//
// This file is part of the BOUML Uml Toolkit.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// e-mail : bouml@free.fr
// home   : http://bouml.free.fr
//
// *************************************************************************

#include <qgrid.h> 
#include <qvbox.h>
#include <qlabel.h>
#include <qcombobox.h> 
#include <qmessagebox.h>
#include <qpushbutton.h> 

#include "StateDialog.h"
#include "StateData.h"
#include "BrowserState.h"
#include "KeyValueTable.h"
#include "UmlWindow.h"
#include "DialogUtil.h"
#include "strutil.h"
#include "UmlDesktop.h"

StateDialog::StateDialog(StateData * d, const QPoint &)
    : MyTabDialog(d->browser_node), state(d) {
  setCaption("State dialog");
  visit = !hasOkButton();  

  BrowserNode * bn = state->browser_node;
  QGrid * grid;
  
  //
  // general tab
  //
  
  grid = new QGrid(2, this);
  grid->setMargin(5);
  grid->setSpacing(5);
  
  new QLabel("name : ", grid);
  edname = new LineEdit(bn->get_name(), grid);
  edname->setReadOnly(visit);
    
  new QLabel("stereotype : ", grid);
  edstereotype = new QComboBox(!visit, grid);
  edstereotype->insertItem(state->get_stereotype());
  if (!visit) {
    edstereotype->insertStringList(BrowserState::default_stereotypes());
    edstereotype->setAutoCompletion(TRUE);
  }
  edstereotype->setCurrentItem(0);
  QSizePolicy sp = edstereotype->sizePolicy();
  sp.setHorData(QSizePolicy::Expanding);
  edstereotype->setSizePolicy(sp);
  
  QVBox * vtab = new QVBox(grid);
  new QLabel("description :", vtab);
  if (! visit)
    connect(new SmallPushButton("Editor", vtab), SIGNAL(clicked()),
	    this, SLOT(edit_description()));
  comment = new MultiLineEdit(grid);
  comment->setReadOnly(visit);
  comment->setText(bn->get_comment());
  //comment->setFont(font);
  
  addTab(grid, "Uml");

  // UML / OCL
  init_tab(uml, state->uml, "Ocl");

  // CPP
  init_tab(cpp, state->cpp, "C++");

  // Java
  init_tab(java, state->java, "Java");
  
  // USER : list key - value
  
  grid = new QGrid(2, this);
  grid->setMargin(5);
  grid->setSpacing(5);
  
  kvtable = new KeyValuesTable(bn, grid, visit);
  addTab(grid, "User");
  
  UmlDesktop::limitsize_center(this, 0.8, 0.8);
}

void StateDialog::init_tab(StDialog & d, StateBehavior & st, const char * lbl) {
  QGrid * grid = new QGrid(2, this);
  grid->setMargin(5);
  grid->setSpacing(5);
  
  new QLabel("Entry\nbehavior : ", grid);
  d.edentry = new MultiLineEdit(grid);
  d.edentry->setText(st.on_entry);
  if (visit)
    d.edentry->setReadOnly(TRUE);
  
  new QLabel("Exit\nbehavior : ", grid);
  d.edexit = new MultiLineEdit(grid);
  d.edexit->setText(st.on_exit);
  if (visit)
    d.edexit->setReadOnly(TRUE);
  
  new QLabel("Do\nbehavior : ", grid);
  d.edactivity = new MultiLineEdit(grid);
  d.edactivity->setText(st.do_activity);
  if (visit)
    d.edactivity->setReadOnly(TRUE);
  
  addTab(grid, lbl);
}

void StateDialog::edit_description() {
  edit(comment->text(), "state_description",
       state, TxtEdit, this, (post_edit) post_edit_description);
}

void StateDialog::post_edit_description(StateDialog * d, QString s)
{
  d->comment->setText(s);
}

void StateDialog::accept() {
  BrowserNode * bn = state->browser_node;
  QString s;
  
  s = edname->text().stripWhiteSpace();
  if ((s != bn->get_name()) &&
      ((BrowserNode *) bn->parent())->wrong_child_name(s, UmlState,
						       bn->allow_spaces(),
						       bn->allow_empty()))
    QMessageBox::critical(0, "Error", s + "\n\nillegal name or already used");
  else {  
    bn->set_name(s);
    state->set_stereotype(edstereotype->currentText().stripWhiteSpace());
    
    uml.accept(state->uml);  
    cpp.accept(state->cpp);  
    java.accept(state->java);    
    
    bn->set_comment(comment->text());
    UmlWindow::set_commented(bn);
    
    kvtable->update(bn);
    
    bn->modified();
    bn->package_modified();
    state->modified();
    
    MyTabDialog::accept();
  }
}

void StDialog::accept(StateBehavior & st) {
  st.on_entry = edentry->text();
  st.on_exit = edexit->text();
  st.do_activity = edactivity->text();
}

==> bouml_2.7.4.tar.gz: bouml_2.7.4/src/dialog/StateDialog.cpp <==
// *************************************************************************
//
// Copyright (C) 2004,2005 Bruno PAGES  All rights reserved.
//
// This file is part of the BOUML Uml Toolkit.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// e-mail : bouml@free.fr
// home   : http://bouml.free.fr
//
// *************************************************************************

#include <qgrid.h> 
#include <qvbox.h>
#include <qlabel.h>
#include <qcombobox.h> 
#include <qmessagebox.h>
#include <qpushbutton.h> 

#include "StateDialog.h"
#include "StateData.h"
#include "BrowserState.h"
#include "KeyValueTable.h"
#include "UmlWindow.h"
#include "DialogUtil.h"
#include "strutil.h"
#include "UmlDesktop.h"
#include "BodyDialog.h"

QSize StateDialog::previous_size;

StateDialog::StateDialog(StateData * d, const QPoint &)
    : MyTabDialog(d->browser_node), state(d) {
  setCaption("State dialog");
  visit = !hasOkButton();  

  BrowserNode * bn = state->browser_node;
  QGrid * grid;
  
  //
  // general tab
  //
  
  grid = new QGrid(2, this);
  grid->setMargin(5);
  grid->setSpacing(5);
  
  new QLabel("name : ", grid);
  edname = new LineEdit(bn->get_name(), grid);
  edname->setReadOnly(visit);
    
  new QLabel("stereotype : ", grid);
  edstereotype = new QComboBox(!visit, grid);
  edstereotype->insertItem(state->get_stereotype());
  if (!visit) {
    edstereotype->insertStringList(BrowserState::default_stereotypes());
    edstereotype->setAutoCompletion(TRUE);
  }
  edstereotype->setCurrentItem(0);
  QSizePolicy sp = edstereotype->sizePolicy();
  sp.setHorData(QSizePolicy::Expanding);
  edstereotype->setSizePolicy(sp);
  
  QVBox * vtab = new QVBox(grid);
  new QLabel("description :", vtab);
  if (! visit)
    connect(new SmallPushButton("Editor", vtab), SIGNAL(clicked()),
	    this, SLOT(edit_description()));
  comment = new MultiLineEdit(grid);
  comment->setReadOnly(visit);
  comment->setText(bn->get_comment());
  //comment->setFont(font);
  
  addTab(grid, "Uml");

  // UML / OCL
  init_tab(uml, state->uml, "Ocl");

  // CPP
  init_tab(cpp, state->cpp, "C++");

  // Java
  init_tab(java, state->java, "Java");
  
  // USER : list key - value
  
  grid = new QGrid(2, this);
  grid->setMargin(5);
  grid->setSpacing(5);
  
  kvtable = new KeyValuesTable(bn, grid, visit);
  addTab(grid, "User");

  UmlDesktop::limitsize_center(this, previous_size, 0.8, 0.8);
}

StateDialog::~StateDialog() {
  previous_size = size();
  
  while (!edits.isEmpty())
    edits.take(0)->close();
}

void StateDialog::init_tab(StDialog & d, StateBehavior & st, const char * lbl) {
  QGrid * grid = new QGrid(2, this);
  grid->setMargin(5);
  grid->setSpacing(5);
  
  new QLabel("Entry\nbehavior : ", grid);
  d.edentry = new MultiLineEdit(grid);
  d.edentry->setText(st.on_entry);
  if (visit)
    d.edentry->setReadOnly(TRUE);
  
  new QLabel("Exit\nbehavior : ", grid);
  d.edexit = new MultiLineEdit(grid);
  d.edexit->setText(st.on_exit);
  if (visit)
    d.edexit->setReadOnly(TRUE);
  
  new QLabel("Do\nbehavior : ", grid);
  d.edactivity = new MultiLineEdit(grid);
  d.edactivity->setText(st.do_activity);
  if (visit)
    d.edactivity->setReadOnly(TRUE);
  
  addTab(grid, lbl);
}

void StateDialog::edit_description() {
  edit(comment->text(), "state_description", state, TxtEdit,
       this, (post_edit) post_edit_description, edits);
}

void StateDialog::post_edit_description(StateDialog * d, QString s)
{
  d->comment->setText(s);
}

void StateDialog::accept() {
  if (!check_edits(edits))
    return;
    
  BrowserNode * bn = state->browser_node;
  QString s;
  
  s = edname->text().stripWhiteSpace();
  if ((s != bn->get_name()) &&
      ((BrowserNode *) bn->parent())->wrong_child_name(s, UmlState,
						       bn->allow_spaces(),
						       bn->allow_empty()))
    QMessageBox::critical(0, "Error", s + "\n\nillegal name or already used");
  else {  
    bn->set_name(s);
    state->set_stereotype(edstereotype->currentText().stripWhiteSpace());
    
    uml.accept(state->uml);  
    cpp.accept(state->cpp);  
    java.accept(state->java);    
    
    bn->set_comment(comment->text());
    UmlWindow::set_commented(bn);
    
    kvtable->update(bn);
    
    bn->modified();
    bn->package_modified();
    state->modified();
    
    MyTabDialog::accept();
  }
}

void StDialog::accept(StateBehavior & st) {
  st.on_entry = edentry->text();
  st.on_exit = edexit->text();
  st.do_activity = edactivity->text();
}
